summaryrefslogtreecommitdiffstats
path: root/src/titlefactor.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /src/titlefactor.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/titlefactor.cpp')
-rw-r--r--src/titlefactor.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/src/titlefactor.cpp b/src/titlefactor.cpp
index e09fe73..0d48c28 100644
--- a/src/titlefactor.cpp
+++ b/src/titlefactor.cpp
@@ -9,16 +9,16 @@
#include "titlefactor.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qgroupbox.h>
-#include <qslider.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
-#include <qimage.h>
-#include <qpixmap.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqgroupbox.h>
+#include <tqslider.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqimage.h>
+#include <tqpixmap.h>
static const unsigned char img0_titlefactor[] = {
0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
@@ -243,64 +243,64 @@ static const unsigned char img0_titlefactor[] = {
/*
* Constructs a titleFactor as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-titleFactor::titleFactor( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+titleFactor::titleFactor( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
- QImage img;
+ TQImage img;
img.loadFromData( img0_titlefactor, sizeof( img0_titlefactor ), "PNG" );
image0 = img;
if ( !name )
setName( "titleFactor" );
setIcon( image0 );
- titleFactorLayout = new QGridLayout( this, 1, 1, 5, 6, "titleFactorLayout");
+ titleFactorLayout = new TQGridLayout( this, 1, 1, 5, 6, "titleFactorLayout");
- lbTitle = new QLabel( this, "lbTitle" );
- QFont lbTitle_font( lbTitle->font() );
+ lbTitle = new TQLabel( this, "lbTitle" );
+ TQFont lbTitle_font( lbTitle->font() );
lbTitle_font.setBold( TRUE );
lbTitle->setFont( lbTitle_font );
titleFactorLayout->addWidget( lbTitle, 0, 0 );
- gbTitle = new QGroupBox( this, "gbTitle" );
- gbTitle->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, gbTitle->sizePolicy().hasHeightForWidth() ) );
- gbTitle->setAlignment( int( QGroupBox::AlignVCenter ) );
+ gbTitle = new TQGroupBox( this, "gbTitle" );
+ gbTitle->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, gbTitle->sizePolicy().hasHeightForWidth() ) );
+ gbTitle->tqsetAlignment( int( TQGroupBox::AlignVCenter ) );
gbTitle->setFlat( FALSE );
gbTitle->setCheckable( TRUE );
gbTitle->setChecked( FALSE );
gbTitle->setColumnLayout(0, Qt::Vertical );
- gbTitle->layout()->setSpacing( 1 );
- gbTitle->layout()->setMargin( 6 );
- gbTitleLayout = new QGridLayout( gbTitle->layout() );
- gbTitleLayout->setAlignment( Qt::AlignTop );
+ gbTitle->tqlayout()->setSpacing( 1 );
+ gbTitle->tqlayout()->setMargin( 6 );
+ gbTitleLayout = new TQGridLayout( gbTitle->tqlayout() );
+ gbTitleLayout->tqsetAlignment( TQt::AlignTop );
- tFactor = new QLabel( gbTitle, "tFactor" );
+ tFactor = new TQLabel( gbTitle, "tFactor" );
gbTitleLayout->addWidget( tFactor, 1, 1 );
- slFactor = new QSlider( gbTitle, "slFactor" );
+ slFactor = new TQSlider( gbTitle, "slFactor" );
slFactor->setMinValue( 100 );
slFactor->setMaxValue( 250 );
- slFactor->setOrientation( QSlider::Horizontal );
- slFactor->setTickmarks( QSlider::Below );
+ slFactor->setOrientation( Qt::Horizontal );
+ slFactor->setTickmarks( TQSlider::Below );
slFactor->setTickInterval( 10 );
gbTitleLayout->addWidget( slFactor, 1, 0 );
titleFactorLayout->addWidget( gbTitle, 1, 0 );
- spacer1 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer1 = new TQSpacerItem( 20, 20, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
titleFactorLayout->addItem( spacer1, 2, 0 );
languageChange();
- resize( QSize(551, 115).expandedTo(minimumSizeHint()) );
+ resize( TQSize(551, 115).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( slFactor, SIGNAL( sliderPressed() ), this, SLOT( slFactorPressed() ) );
- connect( slFactor, SIGNAL( sliderReleased() ), this, SLOT( slFactorReleased() ) );
- connect( slFactor, SIGNAL( valueChanged(int) ), this, SLOT( slFactor_valueChanged(int) ) );
- connect( gbTitle, SIGNAL( toggled(bool) ), this, SLOT( ckAutoClicked(bool) ) );
+ connect( slFactor, TQT_SIGNAL( sliderPressed() ), this, TQT_SLOT( slFactorPressed() ) );
+ connect( slFactor, TQT_SIGNAL( sliderReleased() ), this, TQT_SLOT( slFactorReleased() ) );
+ connect( slFactor, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( slFactor_valueChanged(int) ) );
+ connect( gbTitle, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( ckAutoClicked(bool) ) );
}
/*
@@ -308,7 +308,7 @@ titleFactor::titleFactor( QWidget* parent, const char* name, WFlags fl )
*/
titleFactor::~titleFactor()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -243,64 +243,64 @@ static const unsigned char img0_titlefactor[] = {
/*
- * Constructs a titleFactor as a child of 'parent', with the
+ * Constructs a titleFactor as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -308,7 +308,7 @@ titleFactor::titleFactor( QWidget* parent, const char* name, WFlags fl )
titleFactor::~titleFactor()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*